Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'org.eclipse.egit.ui/src/org/eclipse/egit/ui/internal/history/CommitGraphTable.java')
-rw-r--r--org.eclipse.egit.ui/src/org/eclipse/egit/ui/internal/history/CommitGraphTable.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/org.eclipse.egit.ui/src/org/eclipse/egit/ui/internal/history/CommitGraphTable.java b/org.eclipse.egit.ui/src/org/eclipse/egit/ui/internal/history/CommitGraphTable.java
index e8b2158083..60ee18b1d9 100644
--- a/org.eclipse.egit.ui/src/org/eclipse/egit/ui/internal/history/CommitGraphTable.java
+++ b/org.eclipse.egit.ui/src/org/eclipse/egit/ui/internal/history/CommitGraphTable.java
@@ -229,11 +229,11 @@ class CommitGraphTable {
}
/**
* Returns the SWT Table that backs this CommitGraphTable.
*
* @return Table the SWT Table
*/
- public Table getTable() {
- return table.getTable();
+ public TableViewer getTableView() {
+ return table;
}
}
@@ -229,11 +229,11 @@ class CommitGraphTable {
}
/**
- * Returns the SWT Table that backs this CommitGraphTable.
+ * Returns the SWT TableView of this CommitGraphTable.
*
* @return Table the SWT Table

Back to the top